diff --git a/modules/base/tests/test_table.py b/modules/base/tests/test_table.py
index f4d22c5f0984e1b905c705c71c5c292030109848..731acc185d13a99d523fce617b0fd306ce61f42c 100644
--- a/modules/base/tests/test_table.py
+++ b/modules/base/tests/test_table.py
@@ -1703,7 +1703,7 @@ class TestTable(unittest.TestCase):
     self.assertRaises(ValueError,tab.Select,'c>d')
     self.assertRaises(ValueError,tab.Select,'c+d=5')
 
-    from ost.table_selector import *
+    from ost.table_selector import TableSelector
 
     selector=TableSelector(tab.col_types,tab.col_names,'')
diff --git a/modules/base/pymod/table.py b/modules/base/pymod/table.py
index 207c5ab29f6ceeeeb2e10daf031bb210c932e145..8198b4041321e5e22913d57c0363aaf69bc94840 100644
--- a/modules/base/pymod/table.py
+++ b/modules/base/pymod/table.py
@@ -850,17 +850,15 @@ Statistics for column %(col)s
       #selects rows, where col_a=1 or col_a=2 or col_a=3
       subtab=tab.Select('col_a=1,2,3')
 
-    Only consistent types can be compared. If col_a is of type string and ccol_b is of type int, 
-    following expression would throw an error: 'col_a<ccol_b'
+    Only consistent types can be compared. If col_a is of type string and col_b is of type int, 
+    following expression would throw an error: 'col_a<col_b'
 
     """
 
-    import traceback
     try:
-      from table_selector import *
+      from table_selector import TableSelector
     except:
-      traceback.print_exc()
-      raise ImportError("Tried to import the file table_selector.py, but could not find it!")
+      raise ImportError("Tried to import from the file table_selector.py, but could not find it!")
 
     selector=TableSelector(self.col_types, self.col_names, query)
 